@@ -17,18 +17,20 @@ NULL
   }, force = TRUE)
   shiny::registerInputHandler("shinyGizmo.commoninput", function(x, shinysession, name) {
     if (length(x) == 0) return(NULL)
-    purrr::map(x, ~ {
-      if (length(.) == 0) NA else unlist(.)
+    purrr::imap(x, ~ {
+      name <- .y
+      if (!identical(.x$type, FALSE)) {
+        name <- paste0(name, ":", .x$type)
+      }
+      return(`%:::%`("shiny", "applyInputHandler")(name, .x$value, shinysession))
     })
   }, force = TRUE)
   shiny::registerInputHandler("shinyGizmo.valuebutton", function(x, shinysession, name) {
+    if (is.list(x) && (identical(x$type, FALSE) || identical(x$type, NULL))) {
+      return(`%:::%`("shiny", "applyInputHandler")("value", x$value, shinysession))
+    }
     if (is.list(x) && !is.null(x$type)) {
-      handler <- `%:::%`("shiny", "inputHandlers")$get(x$type)
-      if (!is.null(handler)) {
-        return(handler(x$value))
-      } else {
-        return(x$value)
-      }
+      return(`%:::%`("shiny", "applyInputHandler")(paste0(x$name, ":", x$type), x$value, shinysession))
     }
     return(x)
   }, force = TRUE)
